use axum::extract::Extension;
use axum::extract::Json;
use axum::response::Html;
use axum::response::Redirect;
use serde::Deserialize;
use sqlx::{Pool, Postgres};
use std::sync::Arc;

#[derive(Clone, Debug, Deserialize)]
pub struct RawUser {
    username: String,
    password: String,
}

pub async fn create_user(
    Json(data): Json<RawUser>,
    Extension(pool): Extension<Arc<Pool<Postgres>>>,
) -> Result<Redirect, String> {
    sqlx::query("INSERT INTO users (username, password_hash) VALUES ($1, $2)")
        .bind(data.username)
        .bind(data.password)
        .execute(&*pool)
        .await
        .map_err(|e| e.to_string())?;

    Ok(Redirect::to("/login"))
}

pub async fn login_form() -> Html<String> {
    Html("<html><body>Coming soon!</body></html>".into())
}
